observe abstract method

Object? observe()

Override this method to return the error you want to be used instead of the original error. Or, if you want to keep the original error, return it unaltered. If you want to disable the error, return null.

Implementation

Object? observe();