store property
You can access the store, but do NOT use it to dispatch actions, because the store is still processing the current action, and dispatching another action may cause unexpected behavior. You can use it to read the environment, configuration, and state, if they are relevant to the error you want to return. Example:
Environment get environment => store.environment;
Config get configuration => store.configuration;
AppState get state => store.state;
Implementation
late Store<St> store;