PersistorPrinterDecorator<St> class

A decorator to print persistor information to the console. Use it like this:

var store = Store<AppState>(...,  persistor: PersistorPrinterDecorator(persistor));
Inheritance

Constructors

PersistorPrinterDecorator(Persistor<St> _persistor)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
throttle → Duration?
The default throttle is 2 seconds. Pass null to turn off throttle.
no setteroverride

Methods

addError(Object error, [StackTrace? stackTrace]) → void
Adds an error to be processed by the store, even if the store was not yet created. This is useful in methods like readState, which are usually called before the store exists, and can't show errors to the user by throwing them.
override
deleteState() → Future<void>
Delete the saved state from the persistence.
override
getAndRemoveFirstError() → (Object, StackTrace)?
Gets the first error added by addError (with its stack trace), and removes it. Returns null if there are no errors.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
persistDifference({required St? lastPersistedState, required St newState}) → Future<void>
Save the new state to the persistence. lastPersistedState is the last state that was persisted since the app started, while newState is the new state to be persisted.
override
readState() → Future<St?>
Read the saved state from the persistence. Should return null if the state is not yet persisted. This method should be called only once, when the app starts, before the store is created. The state it returns may become the store's initial-state. If some error occurs while loading the info, we have to deal with it by fixing the problem. In the worse case, if we think the state is corrupted and cannot be fixed, one alternative is deleting all persisted files and returning null.
override
saveInitialState(St state) → Future<void>
Save an initial-state to the persistence.
override
toString() → String
A string representation of this object.
inherited
wrapError(Object error, StackTrace stackTrace) → Object?
If any error is thrown by persistDifference, you have the chance to further process it by using wrapError. Usually this is used to wrap the error inside of another that better describes the failure. For example, you could turn a FileSystemException into a UserException, so that it's shown to the user:
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited