Poll enum
Values
- start → const Poll
-
Start polling. If polling is already active, does nothing. Otherwise, runs the action immediately and starts periodic polling.
- stop → const Poll
-
Stop polling (cancels the timer and does not run the action).
- runNowAndRestart → const Poll
-
Run the action immediately and restart polling from now. If polling is not active, behaves like Poll.start.
- once → const Poll
-
Run the action once immediately. Does not start, stop, cancel, or restart polling.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited